@@ -15,17 +15,16 @@ void RenameLibraryDialog::setupUI()
     newNameLabel = new QLabel(tr("New Library Name : "));
     newNameEdit = new QLineEdit;
     newNameLabel->setBuddy(newNameEdit);
-    connect(newNameEdit, SIGNAL(textChanged(QString)), this, SLOT(nameSetted(QString)));
+    connect(newNameEdit, &QLineEdit::textChanged, this, &RenameLibraryDialog::nameSetted);
 
     accept = new QPushButton(tr("Rename"));
     accept->setDisabled(true);
-    connect(accept, SIGNAL(clicked()), this, SLOT(rename()));
+    connect(accept, &QAbstractButton::clicked, this, &RenameLibraryDialog::rename);
 
     cancel = new QPushButton(tr("Cancel"));
-    connect(cancel, SIGNAL(clicked()), this, SLOT(close()));
+    connect(cancel, &QAbstractButton::clicked, this, &RenameLibraryDialog::close);
 
     auto nameLayout = new QHBoxLayout;
-
     nameLayout->addWidget(newNameLabel);
     nameLayout->addWidget(newNameEdit);
 
@@ -54,7 +53,7 @@ void RenameLibraryDialog::setupUI()
 
 void RenameLibraryDialog::rename()
 {
-    //accept->setEnabled(false);
+    // accept->setEnabled(false);
     emit(renameLibrary(newNameEdit->text()));
 }
 
@@ -69,6 +68,6 @@ void RenameLibraryDialog::nameSetted(const QString &text)
 void RenameLibraryDialog::close()
 {
     newNameEdit->clear();
-    //accept->setEnabled(false);
+    // accept->setEnabled(false);
     QDialog::close();
-}
\ No newline at end of file
+}
